Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::CheckCompatibilityRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for CheckCompatibility.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the resource to check compatibility for. The format is either of following:

  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/compatibility/subjects/*/versions: Check compatibility with one or more versions of the specified subject.
  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/compatibility/subjects/{subject}/versions/{version}: Check compatibility with a specific version of the subject.

Returns:

  • (::String)

    Required. The name of the resource to check compatibility for. The format is either of following:

    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/compatibility/subjects/*/versions: Check compatibility with one or more versions of the specified subject.
    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/compatibility/subjects/{subject}/versions/{version}: Check compatibility with a specific version of the subject.


377
378
379
380
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 377

class CheckCompatibilityRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#references::Array<::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaReference>

Returns Optional. The schema references used by the schema.

Returns:



377
378
379
380
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 377

class CheckCompatibilityRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema::String

Returns Required. The schema payload.

Returns:

  • (::String)

    Required. The schema payload



377
378
379
380
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 377

class CheckCompatibilityRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema_type::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaType

Returns Optional. The schema type of the schema.

Returns:



377
378
379
380
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 377

class CheckCompatibilityRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#verbose::Boolean

Returns Optional. If true, the response will contain the compatibility check result with reasons for failed checks. The default is false.

Returns:

  • (::Boolean)

    Optional. If true, the response will contain the compatibility check result with reasons for failed checks. The default is false.



377
378
379
380
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 377

class CheckCompatibilityRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end