Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::CheckCompatibilityResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Response for CheckCompatibility.

Instance Attribute Summary collapse

Instance Attribute Details

#is_compatible::Boolean

Returns The compatibility check result. If true, the schema is compatible with the resource.

Returns:

  • (::Boolean)

    The compatibility check result. If true, the schema is compatible with the resource.



390
391
392
393
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 390

class CheckCompatibilityResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#messages::Array<::String>

Returns Failure reasons if verbose = true.

Returns:

  • (::Array<::String>)

    Failure reasons if verbose = true.



390
391
392
393
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 390

class CheckCompatibilityResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end