Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::CreateSchemaRegistryRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request to create a schema registry instance.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent whose schema registry instance is to be created. Structured like: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent whose schema registry instance is to be created. Structured like: projects/{project}/locations/{location}



70
71
72
73
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 70

class CreateSchemaRegistryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema_registry::Google::Cloud::ManagedKafka::SchemaRegistry::V1::SchemaRegistry

Returns Required. The schema registry instance to create. The name field is ignored.

Returns:



70
71
72
73
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 70

class CreateSchemaRegistryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema_registry_id::String

Returns Required. The schema registry instance ID to use for this schema registry. The ID must contain only letters (a-z, A-Z), numbers (0-9), and underscores (-). The maximum length is 63 characters. The ID must not start with a number.

Returns:

  • (::String)

    Required. The schema registry instance ID to use for this schema registry. The ID must contain only letters (a-z, A-Z), numbers (0-9), and underscores (-). The maximum length is 63 characters. The ID must not start with a number.



70
71
72
73
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 70

class CreateSchemaRegistryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end