Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::DeleteSchemaModeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for deleting schema mode.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of subject to delete the mode for. The format is

  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/mode/{subject}
  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/mode/{subject}.

Returns:

  • (::String)

    Required. The resource name of subject to delete the mode for. The format is

    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/mode/{subject}
    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/mode/{subject}


480
481
482
483
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 480

class DeleteSchemaModeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end