Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::GetSchemaConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for getting config.

Instance Attribute Summary collapse

Instance Attribute Details

#default_to_global::Boolean

Returns Optional. If true, the config will fall back to the config at the global level if no subject level config is found.

Returns:

  • (::Boolean)

    Optional. If true, the config will fall back to the config at the global level if no subject level config is found.



406
407
408
409
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 406

class GetSchemaConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name to get the config for. It can be either of following:

  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config: Get config at global level.
  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config/{subject}: Get config for a specific subject.

Returns:

  • (::String)

    Required. The resource name to get the config for. It can be either of following:

    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config: Get config at global level.
    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config/{subject}: Get config for a specific subject.


406
407
408
409
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 406

class GetSchemaConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end