Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::GetSchemaModeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for getting schema registry or subject mode.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the mode. The format is

  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/mode/{subject}: mode for a schema registry, or
  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/mode/{subject}: mode for a specific subject in a specific context.

Returns:

  • (::String)

    Required. The resource name of the mode. The format is

    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/mode/{subject}: mode for a schema registry, or
    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/mode/{subject}: mode for a specific subject in a specific context


454
455
456
457
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 454

class GetSchemaModeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end