Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::GetSchemaRegistryRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for GetSchemaRegistry.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the schema registry instance to return. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}.

Returns:

  • (::String)

    Required. The name of the schema registry instance to return. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}



31
32
33
34
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 31

class GetSchemaRegistryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end