Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::GetSchemaRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for GetSchema.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the schema to return. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/schemas/ids/{schema}.

Returns:

  • (::String)

    Required. The name of the schema to return. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/schemas/ids/{schema}



116
117
118
119
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 116

class GetSchemaRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subject::String

Returns Optional. Used to limit the search for the schema ID to a specific subject, otherwise the schema ID will be searched for in all subjects in the given specified context.

Returns:

  • (::String)

    Optional. Used to limit the search for the schema ID to a specific subject, otherwise the schema ID will be searched for in all subjects in the given specified context.



116
117
118
119
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 116

class GetSchemaRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end