Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::ListSubjectsBySchemaIdRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for listing subjects.

Instance Attribute Summary collapse

Instance Attribute Details

#deleted::Boolean

Returns Optional. If true, the response will include soft-deleted subjects. The default is false.

Returns:

  • (::Boolean)

    Optional. If true, the response will include soft-deleted subjects. The default is false.



191
192
193
194
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 191

class ListSubjectsBySchemaIdRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The schema resource whose associated subjects are to be listed. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/schemas/ids/{schema} or projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/schemas/ids/{schema}.

Returns:

  • (::String)

    Required. The schema resource whose associated subjects are to be listed. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/schemas/ids/{schema} or projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/schemas/ids/{schema}



191
192
193
194
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 191

class ListSubjectsBySchemaIdRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subject::String

Returns Optional. The subject to filter the subjects by.

Returns:

  • (::String)

    Optional. The subject to filter the subjects by.



191
192
193
194
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 191

class ListSubjectsBySchemaIdRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end