Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::LookupVersionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for LookupVersion.

Instance Attribute Summary collapse

Instance Attribute Details

#deleted::Boolean

Returns Optional. If true, soft-deleted versions will be included in lookup, no matter if the subject is active or soft-deleted. If false, soft-deleted versions will be excluded. The default is false.

Returns:

  • (::Boolean)

    Optional. If true, soft-deleted versions will be included in lookup, no matter if the subject is active or soft-deleted. If false, soft-deleted versions will be excluded. The default is false.



319
320
321
322
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 319

class LookupVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#normalize::Boolean

Returns Optional. If true, the schema will be normalized before being looked up. The default is false.

Returns:

  • (::Boolean)

    Optional. If true, the schema will be normalized before being looked up. The default is false.



319
320
321
322
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 319

class LookupVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The subject to lookup the schema in. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/subjects/{subject} or projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/subjects/{subject}.

Returns:

  • (::String)

    Required. The subject to lookup the schema in. Structured like: projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/subjects/{subject} or projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/subjects/{subject}



319
320
321
322
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 319

class LookupVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#references::Array<::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaReference>

Returns Optional. The schema references used by the schema.

Returns:



319
320
321
322
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 319

class LookupVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema::String

Returns Required. The schema payload.

Returns:

  • (::String)

    Required. The schema payload



319
320
321
322
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 319

class LookupVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#schema_type::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaType

Returns Optional. The schema type of the schema.

Returns:



319
320
321
322
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 319

class LookupVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end