Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::SchemaConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry_resources.rb

Overview

SchemaConfig represents configuration for a schema registry or a specific subject.

Defined Under Namespace

Modules: CompatibilityType

Instance Attribute Summary collapse

Instance Attribute Details

#alias::String

Returns Optional. The subject to which this subject is an alias of. Only applicable for subject config.

Returns:

  • (::String)

    Optional. The subject to which this subject is an alias of. Only applicable for subject config.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry_resources.rb', line 168

class SchemaConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compatibility type of the schemas.
  module CompatibilityType
    # No compatibility check.
    NONE = 0

    # Backwards compatible with the most recent version.
    BACKWARD = 1

    # Backwards compatible with all previous versions.
    BACKWARD_TRANSITIVE = 2

    # Forwards compatible with the most recent version.
    FORWARD = 3

    # Forwards compatible with all previous versions.
    FORWARD_TRANSITIVE = 4

    # Backwards and forwards compatible with the most recent version.
    FULL = 5

    # Backwards and forwards compatible with all previous versions.
    FULL_TRANSITIVE = 6
  end
end

#compatibility::Google::Cloud::ManagedKafka::SchemaRegistry::V1::SchemaConfig::CompatibilityType

Returns Required. The compatibility type of the schema. The default value is BACKWARD. If unset in a SchemaSubject-level SchemaConfig, defaults to the global value. If unset in a SchemaRegistry-level SchemaConfig, reverts to the default value.

Returns:



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry_resources.rb', line 168

class SchemaConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compatibility type of the schemas.
  module CompatibilityType
    # No compatibility check.
    NONE = 0

    # Backwards compatible with the most recent version.
    BACKWARD = 1

    # Backwards compatible with all previous versions.
    BACKWARD_TRANSITIVE = 2

    # Forwards compatible with the most recent version.
    FORWARD = 3

    # Forwards compatible with all previous versions.
    FORWARD_TRANSITIVE = 4

    # Backwards and forwards compatible with the most recent version.
    FULL = 5

    # Backwards and forwards compatible with all previous versions.
    FULL_TRANSITIVE = 6
  end
end

#normalize::Boolean

Returns Optional. If true, the schema will be normalized before being stored or looked up. The default is false. If unset in a SchemaSubject-level SchemaConfig, the global value will be used. If unset in a SchemaRegistry-level SchemaConfig, reverts to the default value.

Returns:

  • (::Boolean)

    Optional. If true, the schema will be normalized before being stored or looked up. The default is false. If unset in a SchemaSubject-level SchemaConfig, the global value will be used. If unset in a SchemaRegistry-level SchemaConfig, reverts to the default value.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry_resources.rb', line 168

class SchemaConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Compatibility type of the schemas.
  module CompatibilityType
    # No compatibility check.
    NONE = 0

    # Backwards compatible with the most recent version.
    BACKWARD = 1

    # Backwards compatible with all previous versions.
    BACKWARD_TRANSITIVE = 2

    # Forwards compatible with the most recent version.
    FORWARD = 3

    # Forwards compatible with all previous versions.
    FORWARD_TRANSITIVE = 4

    # Backwards and forwards compatible with the most recent version.
    FULL = 5

    # Backwards and forwards compatible with all previous versions.
    FULL_TRANSITIVE = 6
  end
end