Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::SchemaMode

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry_resources.rb

Overview

SchemaMode represents the mode of a schema registry or a specific subject. Four modes are supported:

  • NONE: deprecated. This was the default mode for a subject, but now the default is unset (which means use the global schema registry setting)
  • READONLY: The schema registry is in read-only mode.
  • READWRITE: The schema registry is in read-write mode, which allows limited write operations on the schema.
  • IMPORT: The schema registry is in import mode, which allows more editing operations on the schema for data importing purposes.

Defined Under Namespace

Modules: ModeType

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::ManagedKafka::SchemaRegistry::V1::SchemaMode::ModeType

Returns Required. The mode type of a schema registry (READWRITE by default) or of a subject (unset by default, which means use the global schema registry setting).

Returns:



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry_resources.rb', line 211

class SchemaMode
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode type of the schemas or subjects.
  module ModeType
    # The default / unset value.
    # The subject mode is NONE/unset by default, which means use the global
    # schema registry mode. This should not be used for setting the mode.
    NONE = 0

    # READONLY mode.
    READONLY = 1

    # READWRITE mode.
    READWRITE = 2

    # IMPORT mode.
    IMPORT = 3
  end
end