Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::UpdateSchemaConfigRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb

Overview

Request for updating schema config. On a SchemaSubject-level SchemaConfig, an unset field will be removed from the SchemaConfig.

Instance Attribute Summary collapse

Instance Attribute Details

#compatibility::Google::Cloud::ManagedKafka::SchemaRegistry::V1::SchemaConfig::CompatibilityType

Returns Required. The compatibility type of the schemas. Cannot be unset for a SchemaRegistry-level SchemaConfig. If unset on a SchemaSubject-level SchemaConfig, removes the compatibility field for the SchemaConfig.

Returns:



432
433
434
435
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 432

class UpdateSchemaConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name to update the config for. It can be either of following:

  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config: Update config at global level.
  • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config/{subject}: Update config for a specific subject.

Returns:

  • (::String)

    Required. The resource name to update the config for. It can be either of following:

    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config: Update config at global level.
    • projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/config/{subject}: Update config for a specific subject.


432
433
434
435
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 432

class UpdateSchemaConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#normalize::Boolean

Returns Optional. If true, the schema will be normalized before being stored or looked up. The default is false. Cannot be unset for a SchemaRegistry-level SchemaConfig. If unset on a SchemaSubject-level SchemaConfig, removes the normalize field for the SchemaConfig.

Returns:

  • (::Boolean)

    Optional. If true, the schema will be normalized before being stored or looked up. The default is false. Cannot be unset for a SchemaRegistry-level SchemaConfig. If unset on a SchemaSubject-level SchemaConfig, removes the normalize field for the SchemaConfig.



432
433
434
435
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 432

class UpdateSchemaConfigRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end