Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::CreateVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ManagedKafka::SchemaRegistry::V1::CreateVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb
Overview
Request for CreateVersion.
Instance Attribute Summary collapse
-
#id ⇒ ::Integer
Optional.
-
#normalize ⇒ ::Boolean
Optional.
-
#parent ⇒ ::String
Required.
-
#references ⇒ ::Array<::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaReference>
Optional.
-
#schema ⇒ ::String
Required.
-
#schema_type ⇒ ::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaType
Optional.
-
#version ⇒ ::Integer
Optional.
Instance Attribute Details
#id ⇒ ::Integer
Returns Optional. The schema ID of the schema. If not specified, the schema ID will be generated by the server. If the schema ID is specified, it must not be used by an existing schema that is different from the schema to be created.
280 281 282 283 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 280 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#normalize ⇒ ::Boolean
Returns Optional. If true, the schema will be normalized before being stored. The default is false.
280 281 282 283 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 280 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The subject to create the version for. Structured like:
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/subjects/{subject}
or
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/subjects/{subject}.
280 281 282 283 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 280 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#references ⇒ ::Array<::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaReference>
Returns Optional. The schema references used by the schema.
280 281 282 283 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 280 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#schema ⇒ ::String
Returns Required. The schema payload.
280 281 282 283 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 280 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#schema_type ⇒ ::Google::Cloud::ManagedKafka::SchemaRegistry::V1::Schema::SchemaType
Returns Optional. The type of the schema. It is optional. If not specified, the schema type will be AVRO.
280 281 282 283 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 280 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version ⇒ ::Integer
Returns Optional. The version to create. It is optional. If not specified, the version will be created with the max version ID of the subject increased by 1. If the version ID is specified, it will be used as the new version ID and must not be used by an existing version of the subject.
280 281 282 283 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 280 class CreateVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |