Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::DeleteSubjectRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ManagedKafka::SchemaRegistry::V1::DeleteSubjectRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb
Overview
Request for DeleteSubject.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#permanent ⇒ ::Boolean
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the subject to delete. Structured like:
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/subjects/{subject}
or
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/subjects/{subject}.
226 227 228 229 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 226 class DeleteSubjectRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#permanent ⇒ ::Boolean
Returns Optional. If true, the subject and all associated metadata including the schema ID will be deleted permanently. Otherwise, only the subject is soft-deleted. The default is false. Soft-deleted subjects can still be searched in ListSubjects API call with deleted=true query parameter. A soft-delete of a subject must be performed before a hard-delete.
226 227 228 229 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 226 class DeleteSubjectRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |