Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::ListSchemaVersionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ManagedKafka::SchemaRegistry::V1::ListSchemaVersionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb
Overview
Request for ListSchemaVersions.
Instance Attribute Summary collapse
-
#deleted ⇒ ::Boolean
Optional.
-
#parent ⇒ ::String
Required.
-
#subject ⇒ ::String
Optional.
Instance Attribute Details
#deleted ⇒ ::Boolean
Returns Optional. If true, the response will include soft-deleted versions of the schema, even if the subject is soft-deleted. The default is false.
147 148 149 150 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 147 class ListSchemaVersionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The schema whose schema versions are to be listed. Structured
like:
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/schemas/ids/{schema}
or
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}/schemas/ids/{schema}.
147 148 149 150 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 147 class ListSchemaVersionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subject ⇒ ::String
Returns Optional. The subject to filter the subjects by.
147 148 149 150 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 147 class ListSchemaVersionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |