Class: Google::Cloud::ManagedKafka::SchemaRegistry::V1::ListSubjectsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ManagedKafka::SchemaRegistry::V1::ListSubjectsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb
Overview
Request for listing subjects.
Instance Attribute Summary collapse
-
#deleted ⇒ ::Boolean
Optional.
-
#parent ⇒ ::String
Required.
-
#subject_prefix ⇒ ::String
Optional.
Instance Attribute Details
#deleted ⇒ ::Boolean
Returns Optional. If true, the response will include soft-deleted subjects. The default is false.
171 172 173 174 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 171 class ListSubjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent schema registry/context whose subjects are to be
listed. Structured like:
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}
or
projects/{project}/locations/{location}/schemaRegistries/{schema_registry}/contexts/{context}.
171 172 173 174 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 171 class ListSubjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subject_prefix ⇒ ::String
Returns Optional. The context to filter the subjects by, in the format of
:.{context}:. If unset, all subjects in the registry are returned. Set to
empty string or add as
'?subjectPrefix=' at the end of this request to list subjects in the
default context.
171 172 173 174 |
# File 'proto_docs/google/cloud/managedkafka/schemaregistry/v1/schema_registry.rb', line 171 class ListSubjectsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |